@@ -3,7 +3,7 @@
 # ruff: noqa: E402
 
 from .config import get_settings
-from .models import (
+from doplaydo.dodata_core.models import (
     Project,
     Cell,
     Device,
@@ -11,7 +11,10 @@ from .models import (
     Wafer,
     DeviceData,
     Analysis,
+    AnalysisFunction,
+    AnalysisFunctionTargetModel,
 )
+from doplaydo.dodata_core import models as models
 from sqlalchemy.orm import aliased
 from sqlmodel import and_, or_, select
 
@@ -21,19 +24,19 @@ settings = get_settings()
 from .engine import get_session
 
 session = get_session()
-from .db.common import attribute_filter
-from .db.device_data import get_data_by_query
+from .db.common import attribute_filter, analysis_filter
+from .db.device_data import get_data_by_query, get_data_objects_by_query
 
-from .api.device_data import get_data_by_id
-from .api import project
-from .api import device_data
-from .api import analysis
+from .api.device_data import get_data_by_pkey
+from .api import analysis, cell, device, device_data, project
 
-__version__ = "0.1.4"
+__version__ = "0.4.5"
 
 # ruff: noqa: D101
 __all__ = [
     "Analysis",
+    "AnalysisFunction",
+    "AnalysisFunctionTargetModel",
     "Cell",
     "Device",
     "DeviceData",
@@ -44,9 +47,14 @@ __all__ = [
     "analysis",
     "and_",
     "attribute_filter",
+    "analysis_filter",
+    "cell",
+    "device",
     "device_data",
-    "get_data_by_id",
+    "get_data_by_pkey",
     "get_data_by_query",
+    "get_data_objects_by_query",
+    "models",
     "or_",
     "project",
     "select",
